summaryrefslogtreecommitdiffstats
path: root/sound/usb/line6/midibuf.c
diff options
context:
space:
mode:
Diffstat (limited to 'sound/usb/line6/midibuf.c')
-rw-r--r--sound/usb/line6/midibuf.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sound/usb/line6/midibuf.c b/sound/usb/line6/midibuf.c
index 1ff856989fd6..55df0da5f919 100644
--- a/sound/usb/line6/midibuf.c
+++ b/sound/usb/line6/midibuf.c
@@ -1,5 +1,5 @@
/*
* Line6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)
*
@@ -26,7 +26,7 @@ static int midibuf_message_length(unsigned char code)
} else {
/*
Note that according to the MIDI specification 0xf2 is
- the "Song Position Pointer", but this is used by Line6
+ the "Song Position Pointer", but this is used by Line 6
to send sysex messages to the host.
*/
static const int length[] = { -1, 2, -1, 2, -1, -1, 1, 1, 1, 1,
@@ -1,5 +1,5 @@
/*
- * Line6 Linux USB driver - 0.9.1beta
+ * Line 6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)